@@ -1,7 +1,7 @@
 #
 # -*- Perl -*-
-# $Id: bzip2.pl,v 1.16.8.3 2005/06/06 06:13:34 opengl2772 Exp $
-# Copyright (C) 2000-2004 Namazu Project All rights reserved ,
+# $Id: bzip2.pl,v 1.16.8.1 2004/03/22 07:20:20 opengl2772 Exp $
+# Copyright (C) 2000,2004 Namazu Project All rights reserved ,
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@ use strict;
 require 'util.pl';
 
 my $bzip2path = undef;
-my @bzip2opts = undef;
 
 sub mediatype() {
     return ('application/x-bzip2');
@@ -35,7 +34,6 @@ sub mediatype() {
 
 sub status() {
     $bzip2path = util::checkcmd('bzip2');
-    @bzip2opts = ("-cd");
     return 'no' unless (defined $bzip2path);
     return 'yes';
 }
@@ -58,42 +56,28 @@ sub add_magic ($) {
 
 sub filter ($$$$$) {
     my ($orig_cfile, $cont, $weighted_str, $headings, $fields)
-	= @_;
+      = @_;
+
+    my $tmpfile = util::tmpnam('NMZ.bzip2');
 
     util::vprint("Processing bzip2 file ... (using  '$bzip2path')\n");
 
-    my $tmpfile = util::tmpnam('NMZ.bzip2');
     {
-	my $fh = util::efopen("> $tmpfile");
+	my $fh = util::efopen("|$bzip2path -d > $tmpfile");
 	print $fh $$cont;
         util::fclose($fh);
     }
     {
-	my @cmd = ($bzip2path, @bzip2opts, $tmpfile);
-        my $fh_out = IO::File->new_tmpfile();
-        my $status = util::syscmd(
-            command => \@cmd,
-            option => {
-                "stdout" => $fh_out,
-                "stderr" => "/dev/null",
-            },
-        );
-	my $size = util::filesize($fh_out);
-	if ($size == 0) {
-            util::fclose($fh_out);
-            unlink $tmpfile;
-	    return "Unable to convert file ($bzip2path error occurred)";
-	}
+	my $fh = util::efopen("$tmpfile");
+	my $size = util::filesize($fh);
 	if ($size > $conf::FILE_SIZE_MAX) {
-            util::fclose($fh_out);
-            unlink $tmpfile;
-	    return 'Too large bzipped file';
+            util::fclose($fh);
+	    return 'too_large_gzipped_file';
 	}
-	$$cont = util::readfile($fh_out);
-        util::fclose($fh_out);
+	$$cont = util::readfile($fh);
+        util::fclose($fh);
     }
-    unlink $tmpfile;
-
+    unlink($tmpfile);
     return undef;
 }
 
