@@ -1,9 +1,9 @@
 #
 # -*- Perl -*-
-# $Id: excel.pl,v 1.13.4.2 2002/07/31 07:26:58 knok Exp $
+# $Id: excel.pl,v 1.13.4.7 2004/03/22 07:20:20 opengl2772 Exp $
 # Copyright (C) 1997-2000 Satoru Takabayashi ,
 #               1999 NOKUBI Takatsugu, 
-#               2000 Namazu Project All rights reserved.
+#               2000-2004 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 package excel;
 use strict;
 use File::Basename;
-use File::Copy;
 require 'util.pl';
 require 'gfilter.pl';
 require 'html.pl';
@@ -86,7 +85,7 @@ sub filter ($$$$$) {
       = @_;
     my $err = undef;
 
-    if ($convname =~ /xlhtml/i) {
+    if (defined $convname && $convname =~ /xlhtml/i) {
     $err = filter_xl($orig_cfile, $cont, $weighted_str, $headings, $fields);
     } else {
     $err = filter_doccat($orig_cfile, $cont, $weighted_str, $headings, $fields);
@@ -108,6 +107,7 @@ sub filter_xl ($$$$$) {
     {
 	my $fh = util::efopen("> $tmpfile");
 	print $fh $$cont;
+        util::fclose($fh);
     }
 
 #
@@ -119,6 +119,7 @@ sub filter_xl ($$$$$) {
     {
 	my $fh = util::efopen("< $tmpfile2");
 	$$cont = util::readfile($fh);
+        util::fclose($fh);
     }
 
     # Code conversion for Japanese document.
@@ -132,11 +133,14 @@ sub filter_xl ($$$$$) {
 	{
 	    my $fh = util::efopen("> $tmpfile");
 	    print $fh $$cont;
+            util::fclose($fh);
 	}
 	util::systemcmd("$utfconvpath -I$encoding -Oej $tmpfile > $tmpfile2");
 	{
 	    my $fh = util::efopen("< $tmpfile2");
 	    $$cont = util::readfile($fh);
+            util::fclose($fh);
+	    codeconv::normalize_eucjp($cont);
 	}
     } 
 
@@ -170,13 +174,18 @@ sub filter_doccat ($$$$$) {
 
     my $tmpfile  = util::tmpnam('NMZ.excel');
     my $tmpfile2 = util::tmpnam('NMZ.excel2');   
-    copy("$cfile", "$tmpfile2");
+    {
+        my $fh = util::efopen("> $tmpfile2");
+        print $fh $$cont;
+        util::fclose($fh);
+    }
 
     util::systemcmd("$xlconvpath -o e $tmpfile2 > $tmpfile");
 
     {
         my $fh = util::efopen("< $tmpfile");
         $$cont = util::readfile($fh);
+        util::fclose($fh);
     }
 
     unlink($tmpfile);
