@@ -1,7 +1,7 @@
 #
 # -*- Perl -*-
-# $Id: gzip.pl,v 1.16.8.5 2005/06/06 06:13:34 opengl2772 Exp $
-# Copyright (C) 2000-2004 Namazu Project All rights reserved ,
+# $Id: gzip.pl,v 1.16.8.3 2004/03/22 07:20:20 opengl2772 Exp $
+# Copyright (C) 2000,2004 Namazu Project All rights reserved ,
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@ use strict;
 require 'util.pl';
 
 my $gzippath = undef;
-my @gzipopts = undef;
 
 sub mediatype() {
     return ('application/x-gzip');
@@ -36,7 +35,6 @@ sub mediatype() {
 sub status() {
     return 'yes' if (util::checklib('Compress/Zlib.pm'));
     $gzippath = util::checkcmd('gzip');
-    @gzipopts = ("-cd");
     return 'yes' if (defined $gzippath);
     return 'no';
 }
@@ -59,7 +57,7 @@ sub add_magic ($) {
 
 sub filter ($$$$$) {
     my ($orig_cfile, $cont, $weighted_str, $headings, $fields)
-	= @_;
+      = @_;
     my $err = undef;
 
     if (util::checklib('Compress/Zlib.pm')) {
@@ -73,40 +71,24 @@ sub filter ($$$$$) {
 sub filter_file ($) {
     my ($contref) = @_;
 
+    my $tmpfile = util::tmpnam('NMZ.gzip');
+    my $fh = util::efopen("|$gzippath -cd > $tmpfile");
+
     util::vprint("Processing gzip file ... (using  '$gzippath')\n");
 
-    my $tmpfile = util::tmpnam('NMZ.gzip');
-    {
-	my $fh = util::efopen("> $tmpfile");
-	print $fh $$contref;
+    print $fh $$contref;
+    util::fclose($fh);
+    undef $fh;
+    $fh = util::efopen("$tmpfile");
+    my $size = util::filesize($fh);
+    if ($size > $conf::FILE_SIZE_MAX) {
         util::fclose($fh);
+        unlink($tmpfile);
+	return 'too_large_gzipped_file';
     }
-    {
-	my @cmd = ($gzippath, @gzipopts, $tmpfile);
-        my $fh_out = IO::File->new_tmpfile();
-        my $status = util::syscmd(
-            command => \@cmd,
-            option => {
-                "stdout" => $fh_out,
-                "stderr" => "/dev/null",
-            },
-        );
-	my $size = util::filesize($fh_out);
-	if ($size == 0) {
-            util::fclose($fh_out);
-            unlink $tmpfile;
-	    return "Unable to convert file ($gzippath error occurred)";
-	}
-	if ($size > $conf::FILE_SIZE_MAX) {
-            util::fclose($fh_out);
-            unlink $tmpfile;
-	    return 'Too large gzipped file';
-	}
-	$$contref = util::readfile($fh_out);
-        util::fclose($fh_out);
-    }
-    unlink $tmpfile;
-
+    $$contref = util::readfile($fh);
+    util::fclose($fh);
+    unlink($tmpfile);
     return undef;
 }
 
