@@ -1,8 +1,8 @@
 # 
 # -*- Perl -*-
-# $Id: oletaro.pl,v 1.2.4.12 2007-01-18 06:23:22 opengl2772 Exp $
+# $Id: oletaro.pl,v 1.2.4.5 2004/03/20 18:25:05 opengl2772 Exp $
 # 
-# Copyright (C) 2000-2007 Namazu Project All rights reserved.
+# Copyright (C) 2000-2004 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -27,38 +27,46 @@ package oletaro;
 use strict;
 require 'util.pl';
 require 'gfilter.pl';
-require 'olemsword.pl';
-
-use Win32::OLE::Const;
-
-my $version = 0;
 
 sub mediatype() {
-    status();
-
-    if ($version >= 11) {
+    open (SAVEERR,">&STDERR");
+    open (STDERR,">nul");
+    my $const;
+    $const = Win32::OLE::Const->Load("Microsoft Word 11.0 Object Library");
+    if ($const) {
+        open (STDERR,">&SAVEERR");
         return (
             'application/ichitaro7', 'application/x-js-taro'
         );
-    } elsif ($version == 10) {
+    }
+    $const = Win32::OLE::Const->Load("Microsoft Word 10.0 Object Library");
+    if ($const) {
+        open (STDERR,">&SAVEERR");
         return (
             'application/ichitaro5',
             'application/ichitaro6', 'application/ichitaro7',
             'application/x-js-taro'
         );
-    } elsif ($version == 9) {
-        return (
-            'application/ichitaro4', 'application/ichitaro5',
-            'application/ichitaro6', 'application/ichitaro7',
-            'application/x-js-taro'
-        );
-    } elsif ($version == 8) {
+    }
+    $const = Win32::OLE::Const->Load("Microsoft Word 9.0 Object Library");
+    if ($const) {
+        open (STDERR,">&SAVEERR");
         return (
             'application/ichitaro4', 'application/ichitaro5',
             'application/ichitaro6', 'application/ichitaro7',
             'application/x-js-taro'
         );
     }
+    $const = Win32::OLE::Const->Load("Microsoft Word 8.0 Object Library");
+    if ($const) {
+        open (STDERR,">&SAVEERR");
+        return (
+            'application/ichitaro4', 'application/ichitaro5',
+            'application/ichitaro6', 'application/ichitaro7',
+            'application/x-js-taro'
+        );
+    }
+    open (STDERR,">&SAVEERR");
 
     return (
         'application/ichitaro7', 'application/x-js-taro'
@@ -66,37 +74,14 @@ sub mediatype() {
 }
 
 sub status() {
-    my $const = undef;
-
-    # The check of a dependence filter.
-    return 'no' if (olemsword::status() ne 'yes');
-
     open (SAVEERR,">&STDERR");
     open (STDERR,">nul");
-
-    if (!defined $const) {
-        $const = Win32::OLE::Const->Load("Microsoft Word 12.0 Object Library");
-        $version = 12;
-    }
-    if (!defined $const) {
-        $const = Win32::OLE::Const->Load("Microsoft Word 11.0 Object Library");
-        $version = 11;
-    }
-    if (!defined $const) {
-        $const = Win32::OLE::Const->Load("Microsoft Word 10.0 Object Library");
-        $version = 10;
-    }
-    if (!defined $const) {
-        $const = Win32::OLE::Const->Load("Microsoft Word 9.0 Object Library");
-        $version = 9;
-    }
-    if (!defined $const) {
-        $const = Win32::OLE::Const->Load("Microsoft Word 8.0 Object Library");
-        $version = 8;
-    }
-
+    my $const;
+    $const = Win32::OLE::Const->Load("Microsoft Word 11.0 Object Library");
+    $const = Win32::OLE::Const->Load("Microsoft Word 10.0 Object Library") unless $const;
+    $const = Win32::OLE::Const->Load("Microsoft Word 9.0 Object Library") unless $const;
+    $const = Win32::OLE::Const->Load("Microsoft Word 8.0 Object Library") unless $const;
     open (STDERR,">&SAVEERR");
-
     return 'yes' if (defined $const);
     return 'no';
 }
@@ -110,13 +95,11 @@ sub pre_codeconv() {
 }
 
 sub post_codeconv () {
-    return 0;
+    return 1;
 }
 
 sub add_magic ($) {
     my ($magic) = @_;
-
-    # FIXME: very ad hoc.
     $magic->addFileExts('\\.jsw$', 'application/ichitaro4');
     $magic->addFileExts('\\.jaw$|\\.jtw$', 'application/ichitaro5');
     $magic->addFileExts('\\.jbw$|\\.juw$', 'application/ichitaro6');
@@ -131,8 +114,10 @@ sub filter ($$$$$) {
 
     util::vprint("Processing ichitaro file ...\n");
 
-    my $err = ReadMSWord::ReadDocument($cfile, $cont, $fields, $weighted_str);
-    return $err if (defined $err);
+    $cfile =~ s/\//\\/g;
+    $$cont = "";
+    ReadMSWord::ReadMSWord($cfile, $cont, $fields, $weighted_str);
+    $cfile = defined $orig_cfile ? $$orig_cfile : '';
 
     gfilter::line_adjust_filter($cont);
     gfilter::line_adjust_filter($weighted_str);
