@@ -2,10 +2,10 @@
  * 
  * alias.c - 
  *
- * $Id: alias.c,v 1.15.8.1 2001/09/02 07:13:37 rug Exp $
+ * $Id: alias.c,v 1.15.8.3 2004/03/20 15:25:09 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001,2003 Namazu Project All rights reserved.
  * Copyright (C) 1999 NOKUBI Takatsugu All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
@@ -73,12 +73,15 @@ nmz_add_alias(const char *alias, const char *real)
     newp->alias = malloc(strlen(alias) + 1);
     if (newp->alias == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
+         free(newp);
 	 return FAILURE;
     }
 
     newp->real = malloc(strlen(real) + 1);
     if (newp->real == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
+         free(newp->alias);
+         free(newp);
 	 return FAILURE;
     }
 
