@@ -2,10 +2,10 @@
  * 
  * hlist.c -
  * 
- * $Id: hlist.c,v 1.51.4.5 2001/12/21 05:36:40 knok Exp $
+ * $Id: hlist.c,v 1.51.4.15 2004/04/01 15:32:53 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000,2001 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001,2003,2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -114,6 +114,11 @@ field_sort(NmzResult hlist)
 
 	hlist.data[i].field = malloc(leng + 1);
 	if (hlist.data[i].field == NULL) {
+            int j;
+            for (j = 0; j < i; j++) {
+	        free(hlist.data[j].field);
+	        hlist.data[j].field = NULL;
+            }
 	    nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
 	    return FAILURE;
 	}
@@ -129,6 +134,7 @@ field_sort(NmzResult hlist)
 
     for (i = 0; i < hlist.num; i++) {
 	free(hlist.data[i].field);
+	hlist.data[i].field = NULL;
     }
     return 0;
 }
@@ -356,6 +362,10 @@ nmz_ormerge(NmzResult left, NmzResult right)
     int i, j, v, n;
     NmzResult val;
 
+    val.num  = 0;
+    val.data = NULL;
+    val.stat = SUCCESS;
+
     if ((left.stat  != SUCCESS || left.num <= 0) && 
 	(right.stat != SUCCESS || right.num <= 0)) 
     {
@@ -378,8 +388,10 @@ nmz_ormerge(NmzResult left, NmzResult right)
         return val;
 
     for (v = 0, i = 0, j = 0; i < left.num; i++) {
-	for (; left.data[i].docid >= right.data[j].docid && j < right.num; j++) {
-	    if (left.data[i].docid == right.data[j].docid) {
+	for (; j < right.num; j++) {
+	    if (left.data[i].docid < right.data[j].docid) {
+                break;
+	    } else if (left.data[i].docid == right.data[j].docid) {
 
                 if (nmz_is_tfidfmode()) {
                     left.data[i].score = 
@@ -443,6 +455,8 @@ nmz_free_hlist(NmzResult hlist)
 {
     if (hlist.stat != SUCCESS || hlist.num <= 0) return;
     free(hlist.data);
+    hlist.data = NULL;
+    hlist.num = 0;
 }
 
 void 
@@ -466,6 +480,10 @@ nmz_merge_hlist(NmzResult *hlists)
     int i, n;
     NmzResult value;
 
+    value.num  = 0;
+    value.data = NULL;
+    value.stat = SUCCESS;
+
     if (nmz_get_idxnum() == 1) {
 	return hlists[0];
     }
@@ -512,6 +530,7 @@ nmz_do_date_processing(NmzResult hlist)
 	{
 	    nmz_set_dyingmsg(nmz_msg("%s: %s", NMZ.t, strerror(errno)));
 	    hlist.stat = ERR_FATAL;
+            fclose(date_index);
             return hlist; /* error */
         }
         nmz_fread(&hlist.data[i].date, 
@@ -539,11 +558,10 @@ nmz_do_date_processing(NmzResult hlist)
 NmzResult 
 nmz_get_hlist(int index)
 {
-    int n, *buf, i;
     NmzResult hlist;
-    double idf = 1.0;
 
     hlist.num  = 0;
+    hlist.data = NULL;
     hlist.stat = SUCCESS;
 
     if (-1 == fseek(Nmz.i, nmz_getidxptr(Nmz.ii, index), 0)) {
@@ -551,33 +569,53 @@ nmz_get_hlist(int index)
 	return hlist; /* error */
     }
 
-    nmz_get_unpackw(Nmz.i, &n);
-
-    if (nmz_is_tfidfmode() &&
-	(nmz_get_querytokennum() > 1
-	 /* 0th token is a phrase. */
-	 || strchr(nmz_get_querytoken(0), '\t') != NULL)) 
     {
-        idf = log((double)document_number / (n/2)) / log(2);
-	nmz_debug_printf("idf: %f (N:%d, n:%d)\n", idf, document_number, n/2);
-    }
-
-    if (n > nmz_get_maxhit() * 2) {  
-        /* '* 2' means NMZ.i contains a file-ID and a score. */
-        hlist.stat = ERR_TOO_MUCH_HIT;
-    } else {
+        int n, *buf, i;
+        double idf = 1.0;
 	int sum = 0;
-	buf = malloc(n * sizeof(int)); /* with pelnty margin */
+	int hit;
+	int maxhit = nmz_get_maxhit();
+	int bersize;
+	int totalsize;
+
+        nmz_get_unpackw(Nmz.i, &bersize);
+
+	hit = (bersize < maxhit * 2 ? bersize : maxhit * 2);
+	buf = malloc(hit * sizeof(int));
 	if (buf == NULL) {
 	    nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
 	    hlist.data = NULL;
 	    hlist.stat = ERR_FATAL;
 	    return hlist;
 	}
-	n = nmz_read_unpackw(Nmz.i, buf, n) / 2;
+
+	n = 0;
+	totalsize = 0;
+        while (totalsize < bersize) {
+            if (n == hit) {
+                hlist.stat = ERR_TOO_MUCH_HIT;
+                free(buf);
+                return hlist;
+            }
+            totalsize += nmz_get_unpackw(Nmz.i, &buf[n]);
+            n++;
+        }
+        n /= 2;
+
+        if (nmz_is_tfidfmode() &&
+	    (nmz_get_querytokennum() > 1
+	     /* 0th token is a phrase. */
+	     || strchr(nmz_get_querytoken(0), '\t') != NULL)) 
+        {
+            idf = log((double)document_number / n) / log(2);
+	    nmz_debug_printf("idf: %f (N:%d, n:%d)\n", idf, document_number, n);
+        }
+
 	nmz_malloc_hlist(&hlist, n);
-	if (hlist.stat == ERR_FATAL)
+	if (hlist.stat == ERR_FATAL) {
+	    free(buf);
 	    return hlist;
+        }
 	
 	for (i = 0; i < n; i++) {
 	    hlist.data[i].docid = *(buf + i * 2) + sum;
@@ -624,6 +662,10 @@ nmz_reverse_hlist(NmzResult hlist)
     int m, n;
     NmzResult tmp;
 
+    tmp.num  = 0;
+    tmp.data = NULL;
+    tmp.stat = SUCCESS;
+
     nmz_malloc_hlist(&tmp, 1);
     if (tmp.stat == ERR_FATAL)
         return FAILURE;
@@ -650,6 +692,7 @@ void
 nmz_set_sortfield(const char *field)
 {
     strncpy(field_for_sort, field, BUFSIZE - 1);
+    field_for_sort[BUFSIZE - 1] = '\0';
 }
 
 char *
