@@ -2,10 +2,10 @@
  * 
  * parser.c -
  * 
- * $Id: parser.c,v 1.22.4.1 2001/09/02 07:13:37 rug Exp $
+ * $Id: parser.c,v 1.22.4.3 2004/03/20 15:25:10 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001,2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -57,7 +57,7 @@ static int Cp = 0; /* variable that saves current position of parser */
  *
  */
 
-static NmzResult factor();
+static NmzResult factor(void);
 static int andop(void);
 static NmzResult term(void);
 static int orop(void);
@@ -66,8 +66,11 @@ static NmzResult
 factor(void)
 {
     NmzResult val;
+
     val.num  = 0;
+    val.data = NULL;
     val.stat = SUCCESS;
+
     while (1) {
 	char *token = nmz_get_querytoken(Cp);
         if (token == NULL) {
@@ -153,8 +156,15 @@ failedstat(int stat)
 static NmzResult 
 term(void)
 {
-    NmzResult left, right;
     int op;
+    NmzResult left, right;
+
+    left.num  = 0;
+    left.data = NULL;
+    left.stat = SUCCESS;
+    right.num  = 0;
+    right.data = NULL;
+    right.stat = SUCCESS;
 
     left = factor();
     if (failedstat(left.stat)) {
@@ -204,6 +214,13 @@ nmz_expr(void)
 {
     NmzResult left, right;
 
+    left.num  = 0;
+    left.data = NULL;
+    left.stat = SUCCESS;
+    right.num  = 0;
+    right.data = NULL;
+    right.stat = SUCCESS;
+
     left = term();
     if (failedstat(left.stat)){
 	return left;
