@@ -1,9 +1,9 @@
 /*
  * 
- * $Id: search.c,v 1.86.4.2 2001/12/21 05:36:40 knok Exp $
+ * $Id: search.c,v 1.86.4.12 2004/04/04 15:26:48 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -159,9 +159,15 @@ static NmzResult
 prefix_match(const char *key, int v)
 {
     int i, j, n;
-    NmzResult tmp, val;
     char buf[BUFSIZE], tmpkey[BUFSIZE];
+    NmzResult val, tmp;
+
     val.num  = 0;
+    val.data = NULL;
+    val.stat = SUCCESS;
+    tmp.num  = 0;
+    tmp.data = NULL;
+    tmp.stat = SUCCESS;
 
     strncpy(tmpkey, key, BUFSIZE - 1);
     tmpkey[strlen(tmpkey) - 1] = '\0';
@@ -230,14 +236,20 @@ detect_search_mode(const char *key) {
         return FIELD_MODE;
     }
     if (*key == '/' && key[strlen(key) - 1] == '/') {
-	nmz_debug_printf("do REGEX search\n");
-	return REGEX_MODE;    /* regex match */
+	if (nmz_is_regex_searchmode()) {
+	    nmz_debug_printf("do REGEX search\n");
+	    return REGEX_MODE;    /* regex match */
+	} else {
+	    nmz_debug_printf("disabled REGEX search\n");
+	    return WORD_MODE;
+	}
     } else if (*key == '*' 
                && key[strlen(key) - 1] == '*'
                && *(key + strlen(key) - 2) != '\\' ) 
     {
-	nmz_debug_printf("do REGEX (INTERNAL_MATCH) search\n");
-	return REGEX_MODE;    /* internal match search (treated as regex) */
+	    nmz_debug_printf("do REGEX (INTERNAL_MATCH) search\n");
+	    return REGEX_MODE;    /* internal match search (treated as regex) */
+	    /* [*keyword*] is always enabled */
     } else if (key[strlen(key) - 1] == '*'
         && *(key + strlen(key) - 2) != '\\')
     {
@@ -246,6 +258,7 @@ detect_search_mode(const char *key) {
     } else if (*key == '*') {
 	nmz_debug_printf("do REGEX (SUFFIX_MATCH) search\n");
 	return REGEX_MODE;    /* suffix match  (treated as regex)*/
+	/* [*keyword] is always enabled */
     }
     
     if (strchr(key, '\t')) {
@@ -375,6 +388,7 @@ open_phrase_index_files(FILE **phrase, FILE **phrase_index)
     *phrase_index = fopen(NMZ.pi, "rb");
     if (*phrase_index == NULL) {
         nmz_debug_printf("%s: %s", NMZ.pi, strerror(errno));
+        fclose(*phrase);
         return 1;
     }
     return 0;
@@ -385,12 +399,14 @@ open_phrase_index_files(FILE **phrase, FILE **phrase_index)
  * FIXME: this function is too long and difficult to understand. (but works)
  */
 static NmzResult 
-do_phrase_search(const char *key, NmzResult val)
+do_phrase_search(const char *key, NmzResult src)
 {
     int i, h = 0;
-    char *p, tmpkey[BUFSIZE], *words[QUERY_TOKEN_MAX + 1], *prevword = NULL;
+    char *p, tmpkey[BUFSIZE] = "", *words[QUERY_TOKEN_MAX + 1], *prevword = NULL;
     FILE *phrase, *phrase_index;
     struct nmz_hitnumlist *pr_hitnum = NULL; /* phrase hitnum */
+    /* FIXME: very ad hoc.(for OpenBSD) */
+    NmzResult val = src;
 
     strncpy(tmpkey, key, BUFSIZE - 1);
     p = tmpkey;
@@ -410,6 +426,10 @@ do_phrase_search(const char *key, NmzResult val)
     for (i = 0; ;) {
 	char *q;
 
+	if (*p == '\t') {
+	    p++;
+	    continue;
+	}
 	if (strlen(p) > 0) {
 	    words[i] = p;
 	    i++;
@@ -428,13 +448,22 @@ do_phrase_search(const char *key, NmzResult val)
 	char *word, word_mix[BUFSIZE];
 	NmzResult tmp;
 
+        tmp.num  = 0;
+        tmp.data = NULL;
+        tmp.stat = SUCCESS;
+
         word = words[i];
 	tmp = do_word_search(word, val);
-	if (tmp.stat == ERR_FATAL) 
+	if (tmp.stat == ERR_FATAL) {
+            fclose(phrase);
+            fclose(phrase_index);
 	    return tmp;
+        }
 
 	pr_hitnum = nmz_push_hitnum(pr_hitnum, word, tmp.num, tmp.stat);
 	if (pr_hitnum == NULL) {
+            fclose(phrase);
+            fclose(phrase_index);
 	    tmp.stat = ERR_FATAL;
 	    return tmp;
 	}
@@ -453,6 +482,8 @@ do_phrase_search(const char *key, NmzResult val)
 	    nmz_debug_printf("\nhash:: <%s, %s>: h:%d, val.num:%d\n",
 			     prevword, word, h, val.num);
 	    if (val.stat == ERR_FATAL) {
+                fclose(phrase);
+                fclose(phrase_index);
 		return val;
 	    }
 	}
@@ -469,6 +500,8 @@ do_phrase_search(const char *key, NmzResult val)
         /* Push dummy element */
 	cur = nmz_push_hitnum(cur, "", 0, SUCCESS);
 	if (cur == NULL) {
+            fclose(phrase);
+            fclose(phrase_index);
 	    val.stat = ERR_FATAL;
 	    return val;
 	}
@@ -697,24 +730,30 @@ check_access(void)
 static enum nmz_stat
 open_index_files(void)
 {
-    Nmz.wi = fopen(NMZ.wi, "rb"); /* Check NMZ.wi at first to recognize index format */
-    if (Nmz.wi == NULL) {
-        nmz_debug_printf("%s: %s", NMZ.wi, strerror(errno));
-	return ERR_OLD_INDEX_FORMAT;
-    }
     Nmz.i = fopen(NMZ.i, "rb");
     if (Nmz.i == NULL) {
         nmz_debug_printf("%s: %s", NMZ.i, strerror(errno));
 	return ERR_CANNOT_OPEN_INDEX;
     }
+    Nmz.wi = fopen(NMZ.wi, "rb"); /* Check NMZ.wi at first to recognize index format */
+    if (Nmz.wi == NULL) {
+        nmz_debug_printf("%s: %s", NMZ.wi, strerror(errno));
+        fclose(Nmz.i);
+	return ERR_OLD_INDEX_FORMAT;
+    }
     Nmz.ii = fopen(NMZ.ii, "rb");
     if (Nmz.ii == NULL) {
         nmz_debug_printf("%s: %s", NMZ.ii, strerror(errno));
+        fclose(Nmz.wi);
+        fclose(Nmz.i);
 	return ERR_CANNOT_OPEN_INDEX;
     }
     Nmz.w = fopen(NMZ.w, "rb");
     if (Nmz.w == NULL) {
         nmz_debug_printf("%s: %s", NMZ.w, strerror(errno));
+        fclose(Nmz.ii);
+        fclose(Nmz.wi);
+        fclose(Nmz.i);
 	return ERR_CANNOT_OPEN_INDEX;
     }
 
@@ -826,6 +865,7 @@ make_fullpathname_index(int n)
     nmz_pathcat(base, NMZ.field);
     nmz_pathcat(base, NMZ.t);
     nmz_pathcat(base, NMZ.access);
+    nmz_pathcat(base, NMZ.warnlog);
 }
 
 /*
@@ -889,7 +929,7 @@ int
 nmz_binsearch(const char *key, int prefix_match_mode)
 {
     int l, r, x, e = 0, i;
-    char term[BUFSIZE], tmpkey[BUFSIZE];
+    char term[BUFSIZE], tmpkey[BUFSIZE] = "";
 
     strncpy(tmpkey, key, BUFSIZE - 1);
     lrget( &l, &r);
@@ -950,8 +990,17 @@ nmz_binsearch(const char *key, int prefix_match_mode)
 NmzResult 
 nmz_search(const char *query)
 {
-    NmzResult hlist, tmp[INDEX_MAX];
     int i, ret;
+    NmzResult hlist, tmp[INDEX_MAX];
+
+    hlist.num  = 0;
+    hlist.data = NULL;
+    hlist.stat = SUCCESS;
+    for (i = 0; i < INDEX_MAX; i++) {
+        tmp[i].num  = 0;
+        tmp[i].data = NULL;
+        tmp[i].stat = SUCCESS;
+    }
 
     if (normalize_idxnames() != SUCCESS) {
 	hlist.stat = ERR_FATAL;
@@ -1031,10 +1080,12 @@ nmz_search(const char *query)
 
 
 NmzResult 
-nmz_do_searching(const char *key, NmzResult val)
+nmz_do_searching(const char *key, NmzResult src)
 {
     enum nmz_searchmethod mode;
-    char tmpkey[BUFSIZE];
+    char tmpkey[BUFSIZE] = "";
+    /* FIXME: very ad hoc.(for OpenBSD) */
+    NmzResult val = src;
 
     strncpy(tmpkey, key, BUFSIZE - 1);
 
