@@ -193,12 +193,12 @@ $KAKASI = "module_kakasi -ieuc -oeuc -w";
 #
 # ChaSen 1.51 or later (simple wakatigaki)
 #
-$CHASEN = "no";
+$CHASEN = "/usr/local/bin/chasen -j -F '\%m '";
 
 #
 # ChaSen 1.51 or later (with noun words extraction)
 #
-$CHASEN_NOUN = "no";
+$CHASEN_NOUN = "/usr/local/bin/chasen -j -F '\%m %H\\n'";
 
 #
 # Default Japanese processer: KAKASI or ChaSen.
