@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: util.pl,v 1.22.4.5 2001/09/16 22:42:27 makoto Exp $
+# $Id: util.pl,v 1.22.4.6 2004/03/18 15:54:09 opengl2772 Exp $
 # Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
 # Copyright (C) 2000,2001 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
@@ -64,6 +64,21 @@ sub fopen ($) {
     return $fh;
 }
 
+sub fclose ($) {
+    my ($arg) = @_;
+
+    if (ref $arg) {
+        if ($arg =~ /^(IO::File|FileHandle)/) {
+            my $fh = $arg;
+            $fh->close();
+            return undef;
+        }
+    }
+
+    warn "$arg: " . _("not an IO::File/FileHandle object!\n");
+    return undef;
+}
+
 sub dprint (@) {
     if ($var::Opt{'debug'}) {
 	for my $str (@_) {
@@ -116,7 +131,7 @@ sub readfile ($) {
 	if ($arg =~ /^(IO::File|FileHandle)/) {
 	    $fh = $arg;
 	} else {
-	    warn "$arg: "._("not an IO::File/FileHandle object!\n");
+	    warn "$arg: " . _("not an IO::File/FileHandle object!\n");
 	    return '';
 	}
     } else {
@@ -131,9 +146,35 @@ sub readfile ($) {
 #    }
     read $fh, $cont, $size;
 
+    unless (ref $arg) {
+        fclose($fh);
+    }
     return $cont;
 }
 
+sub writefile ($$) {
+    my ($arg, $cont) = @_;
+
+    my $fh;
+    if (ref $arg) {
+        if ($arg =~ /^(IO::File|FileHandle)/) {
+            $fh = $arg;
+        } else {
+            warn "$arg: " . _("not an IO::File/FileHandle object!\n");
+            return undef;
+        }
+    } else {
+        $fh = efopen("> $arg");
+    }
+
+    print $fh $$cont;
+
+    unless (ref $arg) {
+        fclose($fh);
+    }
+    return undef;
+}
+
 sub filesize($) {
     my ($arg) = @_;
     my $fh;
@@ -141,7 +182,7 @@ sub filesize($) {
 	if ($arg =~ /^(IO::File|FileHandle)/) {
 	    $fh = $arg;
 	} else {
-	    warn "$arg: "._("not an IO::File/FileHandle object!\n");
+	    warn "$arg: " . _("not an IO::File/FileHandle object!\n");
 	    return '';
 	}
     } else {
@@ -149,6 +190,9 @@ sub filesize($) {
 	                               # 2.0.7 had problem
     }
     my $size = -s $fh;
+    unless (ref $arg) {
+        fclose($fh);
+    }
     return $size;
 }
 
