@@ -2,10 +2,10 @@
  * 
  * namazu.c - search client of Namazu
  *
- * $Id: namazu.c,v 1.102.8.3 2002/01/11 05:16:47 knok Exp $
+ * $Id: namazu.c,v 1.102.8.5 2004/03/20 15:02:51 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2003 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -126,7 +126,7 @@ get_templatedir(void)
 enum nmz_stat 
 namazu_core(char * query, char *subquery)
 {
-    char query_with_subquery[BUFSIZE * 2];
+    char query_with_subquery[BUFSIZE * 2] = "";
     NmzResult hlist;
 
     /* Make full-pathname of NMZ.{head,foot,msg,body,slog}.?? */
