@@ -1,8 +1,8 @@
 /*
- * $Id: output.c,v 1.80.4.13 2002/03/13 08:37:36 knok Exp $
+ * $Id: output.c,v 1.80.4.17 2004/03/20 15:02:51 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -117,7 +117,7 @@ static void
 emprint(char *s, int entity_encode)
 {
     int i;
-    for (i = 0; *s && i < BUFSIZE; s++) {
+    for (i = 0; i < BUFSIZE * 16 && *s; s++) {
 	if (*s == EM_START_MARK) {
 	    fputs(emphasis_start_tag, stdout);
 	    continue;
@@ -150,11 +150,11 @@ emprint(char *s, int entity_encode)
 static void
 unhtml_buffer(char *ostr) {
     int f, i;
-    char buf[BUFSIZE], *str;
+    char buf[BUFSIZE] = "", *str;
     int len;
     len = strlen(ostr) + 1;
     str = ostr;
-    for (f = 0, i = 0; *str && i < BUFSIZE; str++) {
+    for (f = 0, i = 0; i < BUFSIZE && *str; str++) {
 
 	/* Iso-2022-jp handling */
 	if ((strncmp(str, "\033$", 2) == 0)
@@ -214,12 +214,13 @@ unhtml_buffer(char *ostr) {
     }
     buf[i] = '\0';
     strncpy(ostr, buf, len);
+    ostr[len - 1] = '\0';
 }
 static void 
 fputs_without_html_tag(const char *str, FILE *fp)
 {
-    char buf[BUFSIZE];
-    strncpy(buf, str, BUFSIZE);
+    char buf[BUFSIZE] = "";
+    strncpy(buf, str, BUFSIZE - 1);
     unhtml_buffer(buf);
     fputs(buf, fp);
 }
@@ -315,7 +316,7 @@ is_cgimode(void)
 static char*
 load_nmz_result(const char *basedir)
 {
-    char fname[BUFSIZE], lang_suffix[BUFSIZE], *buf;
+    char fname[BUFSIZE] = "", lang_suffix[BUFSIZE] = "", *buf;
 
     nmz_pathcat(basedir, NMZ.result);
     strncpy(fname, NMZ.result, BUFSIZE - 1);
@@ -387,7 +388,7 @@ print_hlist(NmzResult hlist)
 	 * Prepare large memory for replace_field() for safety.
 	 * FIXME: static memory allocation may cause buffer overflow.
 	 */
-	char result[BUFSIZE * 128];
+	char result[BUFSIZE * 128] = "";
 	int counter;
 	char *template = the_template;
 
@@ -422,7 +423,7 @@ print_hlist(NmzResult hlist)
 	if (is_htmlmode() || is_listmode()) {
 	    compose_result(hlist.data[i], counter, template,  result);
 	} else {
-	    char tmpbuf[BUFSIZE];
+	    char tmpbuf[BUFSIZE] = "";
 	    strncpy(tmpbuf, template, BUFSIZE -1);
 	    tmpbuf[BUFSIZE - 1] = 0;
 	    unhtml_buffer(tmpbuf);
@@ -645,7 +646,7 @@ print_hitnum(int n)
  */
 static void 
 print_msgfile(const char *fname) {
-    char suffix[BUFSIZE], tmpfname[BUFSIZE];
+    char suffix[BUFSIZE] = "", tmpfname[BUFSIZE] = "";
 
     if (nmz_choose_msgfile_suffix(fname, suffix) == SUCCESS) {
 	char *buf;
@@ -695,7 +696,7 @@ static void
 print_errmsg(int errid)
 {
     char *errmsg = nmz_strerror(errid);
-    char buf[BUFSIZE];
+    char buf[BUFSIZE] = "";
     snprintf(buf, BUFSIZE - 1, _("	<h2>Error!</h2>\n<p>%s</p>\n"), errmsg);
     html_print(buf);
 }
