@@ -1,9 +1,9 @@
 /*
  * 
- * $Id: rcfile.c,v 1.31.4.16 2007/12/05 16:59:36 opengl2772 Exp $
+ * $Id: rcfile.c,v 1.31.4.11 2004/04/05 08:51:24 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2007 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2004 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,10 @@
  * 
  */
 
+#include <assert.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <errno.h>
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -30,18 +34,10 @@
 #  include "support.h"
 #endif
 
-#include <assert.h>
-#include <stdio.h>
-#include <stdlib.h>
-
-#ifdef HAVE_ERRNO_H
-#  include <errno.h>
-#endif
-
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
+#include <strings.h>
 #endif
 
 #include "namazu.h"
@@ -59,13 +55,6 @@
 #include "idxname.h"
 #include "output.h"
 #include "score.h"
-#include "charset.h"
-
-/*
- * Extern variables.
- */
-
-extern NMZ_HANDLE handle_charset;
 
 /*
  * Default directory to place namazurc.
@@ -77,8 +66,6 @@ static char *namazurcdir = OPT_CONFDIR;
  */
 static char user_namazurc[BUFSIZE] = "";
 
-static char namazunorc[BUFSIZE] = "";
-
 static char *errmsg  = NULL;
 
 /* suicide time (sec) */
@@ -148,7 +135,6 @@ static enum nmz_stat process_rc_maxmatch ( const char *directive, const StrList
 static enum nmz_stat process_rc_contenttype ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_suicidetime ( const char *directive, const StrList *args );
 static enum nmz_stat process_rc_regexsearch ( const char *directive, const StrList *args );
-static enum nmz_stat process_rc_charset ( const char *directive, const StrList *args );
 
 struct conf_directive {
     char *name;
@@ -177,7 +163,6 @@ static struct conf_directive directive_tab[] = {
     { "CONTENTTYPE",   1, 0, process_rc_contenttype },
     { "SUICIDE_TIME",  1, 0, process_rc_suicidetime },
     { "REGEX_SEARCH",  1, 0, process_rc_regexsearch },
-    { "CHARSET",       2, 0, process_rc_charset },
     { NULL,            0, 0, NULL }
 };
 
@@ -380,18 +365,6 @@ process_rc_regexsearch(const char *directive, const StrList *args)
     return SUCCESS;
 }
 
-static enum nmz_stat
-process_rc_charset(const char *directive, const StrList *args)
-{
-    char *arg1 = args->value;
-    char *arg2 = args->next->value;
-
-    if (nmz_add_strlist(handle_charset, arg1, arg2) != SUCCESS) {
-        return FAILURE;
-    }
-    return SUCCESS;
-}
-
 /* 
  * Get the environment variable of NAMAZURC, NAMAZUCONF or
  * NAMAZUCONFPATH.  and return it. Original of this code is
@@ -428,7 +401,7 @@ get_rc_arg(const char *line, char *arg)
     arg[BUFSIZE - 1] = '\0';
     *arg = '\0';
     if (*line != '"') {
-	size_t n = strcspn(line, " \t");
+	int n = strcspn(line, " \t");
 	if (n >= BUFSIZE) n = BUFSIZE - 1;
 	strncpy(arg, line, n);
 	arg[n] = '\0';     /* Hey, don't forget this after strncpy()! */
@@ -438,7 +411,7 @@ get_rc_arg(const char *line, char *arg)
 	line++;
 	n = 1;
 	do {
-	    size_t nn = strcspn(line, "\"\\");
+	    int nn = strcspn(line, "\"\\");
 	    if (nn >= (BUFSIZE - strlen(arg))) nn = BUFSIZE - strlen(arg) - 1;
 	    strncat(arg, line, nn);
 	    n += nn;
@@ -776,16 +749,7 @@ load_rcfile(const char *fname)
 void
 set_namazurc(const char *arg)
 {
-    strncpy(user_namazurc, arg, BUFSIZE - 1);
-    user_namazurc[BUFSIZE - 1] = '\0';
-}
-
-void
-set_namazunorc(const char *arg)
-{
-    strncpy(namazunorc, arg, BUFSIZE - 1);
-    namazunorc[BUFSIZE - 1] = '\0';
-    nmz_strlower(namazunorc);
+    strcpy(user_namazurc, arg);
 }
 
 /*
@@ -803,20 +767,15 @@ set_namazunorc(const char *arg)
 enum nmz_stat 
 load_rcfiles(void)
 {
-    char *env_norc, _norc[BUFSIZE] = "";
+    char *env_norc, namazunorc[BUFSIZE] = "";
 
     if ((env_norc = getenv("NAMAZUNORC"))) {
-        strncpy(_norc, env_norc, BUFSIZE - 1);
-        _norc[BUFSIZE - 1] = '\0';
-        nmz_strlower(_norc);
-
-        if (namazunorc[0] == '\0') {
-            set_namazunorc(_norc);
-        }
+        strncpy(namazunorc, env_norc, BUFSIZE - 1);
+        namazunorc[BUFSIZE - 1] = '\0';
+        nmz_strlower(namazunorc);
     }
 
-    nmz_debug_printf("NAMAZUNORC: '%s'", _norc);
-    nmz_debug_printf("namazunorc: '%s'", namazunorc);
+    nmz_debug_printf("NAMAZUNORC: '%s'", namazunorc);
 
     /*
      *  1. $(sysconfdir)/$(PACKAGE)/namazurc
